@@ -1,28 +1,26 @@
 """This module defines custom implementation of ``clean`` setuptools command."""
 
 import os
-
-try:
-    from setuptools.command.clean import clean as _clean
-except ImportError:
-    from distutils.command.clean import clean as _clean
-
 from shutil import rmtree
 
+import setuptools  # noqa: F401
+from distutils.command.clean import clean as _clean
+
 from ..constants import CMAKE_BUILD_DIR, CMAKE_INSTALL_DIR, SKBUILD_DIR
-from ..utils import distutils_log, new_style
+from ..utils import distutils_log
 from . import set_build_base_mixin
 
 
-class clean(set_build_base_mixin, new_style(_clean)):
+class clean(set_build_base_mixin, _clean):
     """Custom implementation of ``clean`` setuptools command."""
 
-    def run(self):
+    def run(self) -> None:
         """After calling the super class implementation, this function removes
         the directories specific to scikit-build."""
-        super(clean, self).run()
+        super().run()
         for dir_ in (CMAKE_INSTALL_DIR(), CMAKE_BUILD_DIR(), SKBUILD_DIR()):
             if os.path.exists(dir_):
                 distutils_log.info("removing '%s'", dir_)
-            if not self.dry_run and os.path.exists(dir_):
+            # This seems to be there but isn't typed in the stubs TODO
+            if not self.dry_run and os.path.exists(dir_):  # type: ignore[attr-defined]
                 rmtree(dir_)
