@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 
 """test_cmaker
 ----------------------------------
@@ -9,7 +8,6 @@ Tests for CMaker functionality.
 
 import os
 import re
-import sys
 import textwrap
 
 import pytest
@@ -121,14 +119,14 @@ def test_make(configure_with_cmake_source_dir, capfd):
         if configure_with_cmake_source_dir:
             messages += [
                 "/SRC",
-                "/BUILD/{}".format(to_unix_path(CMAKE_BUILD_DIR())),
-                "/BUILD/{}/./foo.txt".format(to_unix_path(CMAKE_INSTALL_DIR())),
+                f"/BUILD/{to_unix_path(CMAKE_BUILD_DIR())}",
+                f"/BUILD/{to_unix_path(CMAKE_INSTALL_DIR())}/./foo.txt",
             ]
         else:
             messages += [
                 "/SRC",
-                "/SRC/{}".format(to_unix_path(CMAKE_BUILD_DIR())),
-                "/SRC/{}/./foo.txt".format(to_unix_path(CMAKE_INSTALL_DIR())),
+                f"/SRC/{to_unix_path(CMAKE_BUILD_DIR())}",
+                f"/SRC/{to_unix_path(CMAKE_INSTALL_DIR())}/./foo.txt",
             ]
 
         out, _ = capfd.readouterr()
@@ -196,20 +194,18 @@ def test_configure_with_cmake_args(capfd):
             "CMAKE_EXPECTED_FOO",
             "PYTHON_VERSION_STRING",
             "SKBUILD",
+            "PYTHON_EXECUTABLE",
+            "PYTHON_INCLUDE_DIR",
+            "PYTHON_LIBRARY",
         ]
 
-        find_python_prefixes = [
-            "Python{}".format(sys.version_info[0]),
-            "Python",
-            "PYTHON",
-        ]
-
-        for prefix in find_python_prefixes:
+        for prefix in ["Python3", "Python"]:
             unused_vars.extend(
                 [
-                    (prefix + "_EXECUTABLE"),
-                    (prefix + "_INCLUDE_DIR"),
-                    (prefix + "_LIBRARY"),
+                    f"{prefix}_EXECUTABLE",
+                    f"{prefix}_ROOT_DIR",
+                    f"{prefix}_FIND_IMPLEMENTATIONS",
+                    f"{prefix}_FIND_REGISTRY",
                 ]
             )
 
@@ -232,7 +228,7 @@ def test_configure_with_cmake_args(capfd):
               )
             endforeach()
             """
-            ).format("\n".join("  ${{{}}}".format(unused) for unused in unused_vars))
+            ).format("\n".join(f"  ${{{unused}}}" for unused in unused_vars))
         )
 
         with push_dir(str(tmp_dir)):
